/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.data.set.internal.filter;

import com.liferay.frontend.data.set.filter.BaseAutocompleteFDSFilter;
import com.liferay.frontend.data.set.filter.FDSFilter;
import com.liferay.frontend.data.set.filter.FDSFilterContextContributor;
import com.liferay.portal.kernel.language.Language;
import com.liferay.portal.kernel.util.HashMapBuilder;

import java.util.Collections;
import java.util.Locale;
import java.util.Map;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marco Leo
 */
@Component(
	property = "frontend.data.set.filter.type=autocomplete",
	service = FDSFilterContextContributor.class
)
public class AutocompleteFDSFilterContextContributor
	implements FDSFilterContextContributor {

	@Override
	public Map<String, Object> getFDSFilterContext(
		FDSFilter fdsFilter, Locale locale) {

		if (fdsFilter instanceof BaseAutocompleteFDSFilter) {
			return _serialize((BaseAutocompleteFDSFilter)fdsFilter, locale);
		}

		return Collections.emptyMap();
	}

	private Map<String, Object> _serialize(
		BaseAutocompleteFDSFilter baseAutocompleteFDSFilter, Locale locale) {

		return HashMapBuilder.<String, Object>put(
			"apiURL", baseAutocompleteFDSFilter.getAPIURL()
		).put(
			"inputPlaceholder",
			_language.get(locale, baseAutocompleteFDSFilter.getPlaceholder())
		).put(
			"itemKey", baseAutocompleteFDSFilter.getItemKey()
		).put(
			"itemLabel", baseAutocompleteFDSFilter.getItemLabel()
		).put(
			"selectionType",
			() -> {
				if (baseAutocompleteFDSFilter.isMultipleSelection()) {
					return "multiple";
				}

				return "single";
			}
		).build();
	}

	@Reference
	private Language _language;

}